==> landing-page-webflow-scripts-1.1.6.tgz: package/src/buyer/buyer-events.js <==
import { PUBLIC_URLS } from '../config/public-endpoints';
import { pushTagToGTM } from '../util/gtm/cos-gtm';
import { userClickHero, userClickRegistration } from '../util/gtm/tags-collection';

/**
 * onClick listener for the toolbar registration button
 */
const initToolbarRegisterButtonClickListener = () => {
  $('.primary-button.buyer.toolbar').on('click', function() {
    // currently pushing to GTM only from the root page
    if (location.pathname === '/') {
      pushTagToGTM(userClickRegistration);
    }

    window.open(PUBLIC_URLS.buyerRegistrationSite, '_blank');
  });
}

/**
 * onClick listener for the hero registration button
 */
const initHeroRegisterButtonClickListener = () => {
  $('.primary-button.hero.buyer').on('click', function() {
    // currently pushing to GTM only from the root page
    if (location.pathname === '/') {
      pushTagToGTM(userClickHero)
    }

    window.open(PUBLIC_URLS.buyerRegistrationSite, '_blank');
  });
}

/**
 * onClick listener for the footer registration button
 */
const initFooterRegisterButtonClickListener = () => {
  $('.primary-button.auction-button.footer-button').on('click', function () {
    window.open(PUBLIC_URLS.buyerRegistrationSite, '_blank');
  });
}

/**
 * buyer click events
 * @returns {{ init: init }}
 */
export const buyerEvents = (() => ({
  init: function () {
    // init onClick listeners
    initToolbarRegisterButtonClickListener();
    initHeroRegisterButtonClickListener();
    initFooterRegisterButtonClickListener();
  }
}))();

==> landing-page-webflow-scripts-1.1.9.tgz: package/src/buyer/buyer-events.js <==
import { PUBLIC_URLS } from '../config/public-endpoints';
import { pushTagToGTM } from '../util/gtm/cos-gtm';
import {
  userClickAuctionRegistration, userClickFAQRegistration, userClickFooterRegistration,
  userClickHeroRegistration,
  userClickRegistration
} from '../util/gtm/tags-collection';

/**
 * onClick listener for the toolbar registration button
 */
const initToolbarRegisterButtonClickListener = () => {
  $('.primary-button.buyer.toolbar').on('click', function() {
    // currently pushing to GTM only from the root page
    if (location.pathname === '/') {
      pushTagToGTM(userClickRegistration);
    }

    window.open(PUBLIC_URLS.buyerRegistrationSite, '_blank');
  });
}

/**
 * onClick listener for the hero registration button
 */
const initHeroRegisterButtonClickListener = () => {
  $('.primary-button.hero.buyer').on('click', function() {
    // currently pushing to GTM only from the root page
    if (location.pathname === '/') {
      pushTagToGTM(userClickHeroRegistration)
    }

    window.open(PUBLIC_URLS.buyerRegistrationSite, '_blank');
  });
}

/**
 * onClick listener for the auction registration button
 */
const initAuctionButtonClickListener = () => {
  $('.primary-button.auction-button').on('click', function() {
    // currently pushing to GTM only from the root page
    if (location.pathname === '/') {
      pushTagToGTM(userClickAuctionRegistration)
    }

    window.open(PUBLIC_URLS.buyerRegistrationSite, '_blank');
  });
}

/**
 * onClick listener for the FAQ registration button
 */
const initFAQRegistrationClickListener = () => {
  $('.primary-button.faq-button').on('click', function() {
    // currently pushing to GTM only from the root page
    if (location.pathname === '/') {
      pushTagToGTM(userClickFAQRegistration)
    }

    window.open(PUBLIC_URLS.buyerRegistrationSite, '_blank');
  });
}

/**
 * onClick listener for the FAQ registration button
 */
const initFooterRegistrationClickListener = () => {
  $('.primary-button.footer-button').on('click', function() {
    // currently pushing to GTM only from the root page
    if (location.pathname === '/') {
      pushTagToGTM(userClickFooterRegistration)
    }

    window.open(PUBLIC_URLS.buyerRegistrationSite, '_blank');
  });
}

/**
 * buyer click events
 * @returns {{ init: init }}
 */
export const buyerEvents = (() => ({
  init: function () {
    // init onClick listeners
    initToolbarRegisterButtonClickListener();
    initHeroRegisterButtonClickListener();
    initAuctionButtonClickListener();
    initFAQRegistrationClickListener();
    initFooterRegistrationClickListener()
  }
}))();
